@@ -42,12 +42,16 @@ def setup( config_user = None ) :
         s_log.write( "Not setup ready!" )
         return( falg )
 
+    handle_key_fromcontainer( )
     unpack_key( )
+    handle_sslverify_fornumericip( )
+    handle_key_public( )
     checkup_workspacedir( )
 
     ready = True
 
     s_log.write( get_config( ) )
+    s_log.write( get_config_alt( ) )
 
     return( True )
 
@@ -61,7 +65,7 @@ def get_key( config_key , default_val = None ) :
         cip = config[ "/config/init/path" ]
         cipt = config[ "/config/init/path_time" ]
 
-        cfp = cd+"/"+cip
+        cfp = cd + "/" + cip
 
     if( config_key in config_alt ) :
         #s_log.write_msg("GET KEY FOUND")
@@ -87,14 +91,62 @@ def checkup_workspacedir( ) :
     if not wd :
         set_key( "sys/workspacedir" , "/tmp/sapiadapter" )
 
+def handle_key_fromcontainer( ) :
+    
+    if not "_CONTAINER_LOCAL_CONFIGENDPOINTKEY" in os.environ : return
+
+    endpoint_key = os.environ[ "_CONTAINER_LOCAL_CONFIGENDPOINTKEY" ]
+
+    if endpoint_key.endswith( "_LOCAL_CONFIGENDPOINTKEY_" ) : return
+
+    set_key_alt( "endpoint/key" , endpoint_key ) 
+
+
+
+
+def handle_key_public( ) :
+
+    if( get_key( "endpoint/url"  ) ) : return
+
+    set_key_alt( "endpoint/url" , "https://sapiomnibus-public.sparc.space" )
+
+def handle_sslverify_fornumericip( ) :
+
+    endpoint_url = get_key( "endpoint/url" )
+
+    if( not endpoint_url ) :
+        return
+
+    #s_log.write(endpoint_url)
+    purl = s_util.url_parse( endpoint_url )
+    #s_log.write(purl.scheme)
+    #s_log.write(purl.hostname)
+    #s_log.write(purl.port)
+
+    if( not purl.hostname ) :
+        return
+
+    if( s_util.is_ip( purl.hostname ) ):
+        set_key_alt( "endpoint/sslverify" , "no" )
+        return
+
+    ########################################################
+
+    host = get_key( "endpoint/host" )
+    s_log.write(host)
+    if(not host): return
+
+    if host.endswith(".test"):
+        set_key_alt( "endpoint/sslverify" , "no" )
+
+
 def unpack_key( ) :
 
-    if "_CONTAINER_LOCAL_CONFIGENDPOINTKEY" in os.environ :
-        endpoint_key = os.environ["_CONTAINER_LOCAL_CONFIGENDPOINTKEY"]
-    else :
-        endpoint_key = get_key( "endpoint/key" )
+    endpoint_key = get_key( "endpoint/key" )
+
+    if( not endpoint_key ) :
+        return
 
-    if not endpoint_key : return
 
     parts = endpoint_key.split( "|" )
 
@@ -108,11 +160,19 @@ def unpack_key( ) :
 
     url = endpoint_url_token[ 0:-67 ]
     token = endpoint_url_token[ -67: ]
+
     if( url[ 0:4 ] != "http" ) : url = "https://" + url
 
+    #s_log.write(url)
+    #purl = s_util.url_parse(url)
+    #s_log.write(purl.scheme)
+    #s_log.write(purl.hostname)
+    #s_log.write(purl.port)
+
     set_key_alt( "endpoint/url" , url )
     set_key_alt( "endpoint/token" , token )
 
+    return
 
 def isready( ) :
     return( ready )
@@ -122,6 +182,11 @@ def get_config( ) :
     # FIXME TODO merge alt config... otherwise you dont have full picture
     # FIXME TODO have log that outputs both config and alt!
     return config
+def get_config_alt( ) :
+    # FIXME TODO merge alt config... otherwise you dont have full picture
+    # FIXME TODO have log that outputs both config and alt!
+    return config_alt
+
 
 def set_key( config_key , config_val ) :
     global config
