@@ -22,7 +22,7 @@ import json
 from datetime import datetime
 #import uuid
 #import hashlib
-from inspect import currentframe,getframeinfo
+from inspect import currentframe , getframeinfo
 from . import s_config , s_util
 
 #####################################################################
@@ -43,7 +43,7 @@ def init( ) :
 
     log_workspacedir = s_config.get_key( "sys/workspacedir" , "/tmp/sapiadapter")
 
-    if(not log_workspacedir): return
+    if( not log_workspacedir ) : return
 
     os.makedirs( log_workspacedir , exist_ok = True )
 
@@ -95,7 +95,8 @@ def write( msg_raw ) :
 
     context = filename + "," + functionname + "," + str( cf.f_lineno )
 
-    msg = "-:::" + log_traceid + ":::" + datetime.now( ).strftime( "%Y_%m_%d-%H_%M_%S" ) + ":::" + context + ":::" + msg
+    # msg = "-:::" + log_traceid + ":::" + datetime.now( ).strftime( "%Y_%m_%d-%H_%M_%S" ) + ":::" + context + ":::" + msg
+    msg = "-:::" + log_traceid + ":::" + s_util.time_getisoformat( ) + ":::" + context + ":::" + msg
     with open( log_filepath , "a+" , 1 ) as log_file :
         log_file.write( msg + "\n" )
 
