@@ -61,11 +61,11 @@ def heartbeat( t = 60 ) :
 
 def server( runner ) :
 
-    s_log.write( "SERVER STARTED" )
+    s_log.write( "SERVER START" )
 
     while True :
 
-        #s_log.write( "SERVER LOOP" )
+        s_log.write( "SERVER LOOP" )
 
         heartbeat( )
 
@@ -74,6 +74,7 @@ def server( runner ) :
         try :
             flag_jobget = s_net.job_get( )
         except Exception as e :
+            s_log.write( "Exception job_get" )
             s_util.printexception( )
             #continue
             prexit( "EXCEPTION job_get" )
@@ -83,9 +84,10 @@ def server( runner ) :
         
         if flag_jobget == False :
 
+            #s_config.get_key( "endpoint/url" ) 
             s_log.write( "ERROR False job_get" )
-            continue
-            #sapi.prexit( "False job_get" )
+            #continue
+            prexit( "False job_get" )
 
         if flag_jobget == None :
             continue
@@ -157,6 +159,8 @@ def server( runner ) :
 
         s_log.write( "OK" )
 
+    s_log.write( "SERVER END" )
+
 
 
 #####################################################################
